@@ -8,7 +8,7 @@
  * Based on the original code of Epona by Lara.
  * Based on the original code of Services by Andy Church. 
  * 
- * $Id: botserv.c 5 2004-03-29 01:29:50Z dane $
+ * $Id: botserv.c 420 2004-10-23 23:42:15Z trystan $
  *
  */
 
@@ -60,6 +60,7 @@ static int do_badwords(User * u);
 static int do_say(User * u);
 static int do_act(User * u);
 void moduleAddBotServCmds(void);
+char *normalizeBuffer(const char *s);
 /*************************************************************************/
 /* *INDENT-OFF* */
 void moduleAddBotServCmds(void) {
@@ -284,84 +285,95 @@ void botchanmsgs(User * u, ChannelInfo * ci, char *buf)
         if (ci->botflags & BS_KICK_BADWORDS) {
             int i;
             int mustkick = 0;
+            char *nbuf = NULL;
             BadWord *bw;
 
-            for (i = 0, bw = ci->badwords; i < ci->bwcount; i++, bw++) {
-                if (!bw->in_use)
-                    continue;
+            /* Normalize the buffer */
+            nbuf = normalizeBuffer(buf);
+            if (nbuf) {
+                for (i = 0, bw = ci->badwords; i < ci->bwcount; i++, bw++) {
+                    if (!bw->in_use)
+                        continue;
 
-                if (bw->type == BW_ANY && stristr(buf, bw->word)) {
-                    mustkick = 1;
-                } else if (bw->type == BW_SINGLE) {
-                    int len = strlen(bw->word);
-
-                    if (!stricmp(buf, bw->word)) {
+                    if (bw->type == BW_ANY && stristr(nbuf, bw->word)) {
                         mustkick = 1;
-                        /* two next if are quite odd isn't it? =) */
-                    } else if ((strchr(buf, ' ') == buf + len)
-                               && (stristr(buf, bw->word) == buf)) {
-                        mustkick = 1;
-                    } else
-                        if ((strrchr(buf, ' ') ==
-                             buf + strlen(buf) - len - 1)
-                            && (stristr(buf, bw->word) ==
-                                buf + strlen(buf) - len)) {
-                        mustkick = 1;
-                    } else {
-                        char *wordbuf = scalloc(len + 3, 1);
+                    } else if (bw->type == BW_SINGLE) {
+                        int len = strlen(bw->word);
 
-                        wordbuf[0] = ' ';
-                        wordbuf[len + 1] = ' ';
-                        wordbuf[len + 2] = '\0';
-                        memcpy(wordbuf + 1, bw->word, len);
-
-                        if (stristr(buf, wordbuf))
+                        if (!stricmp(nbuf, bw->word)) {
                             mustkick = 1;
+                            /* two next if are quite odd isn't it? =) */
+                        } else if ((strchr(nbuf, ' ') == nbuf + len)
+                                   && (stristr(nbuf, bw->word) == nbuf)) {
+                            mustkick = 1;
+                        } else
+                            if ((strrchr(nbuf, ' ') ==
+                                 nbuf + strlen(nbuf) - len - 1)
+                                && (stristr(nbuf, bw->word) ==
+                                    nbuf + strlen(nbuf) - len)) {
+                            mustkick = 1;
+                        } else {
+                            char *wordbuf = scalloc(len + 3, 1);
+
+                            wordbuf[0] = ' ';
+                            wordbuf[len + 1] = ' ';
+                            wordbuf[len + 2] = '\0';
+                            memcpy(wordbuf + 1, bw->word, len);
+
+                            if (stristr(nbuf, wordbuf))
+                                mustkick = 1;
+                        }
+                    } else if (bw->type == BW_START) {
+                        int len = strlen(bw->word);
+
+                        if (!strnicmp(nbuf, bw->word, len)) {
+                            mustkick = 1;
+                        } else {
+                            char *wordbuf = scalloc(len + 2, 1);
+
+                            memcpy(wordbuf + 1, bw->word, len);
+                            wordbuf[0] = ' ';
+                            wordbuf[len + 1] = '\0';
+
+                            if (stristr(nbuf, wordbuf))
+                                mustkick = 1;
+
+                            free(wordbuf);
+                        }
+                    } else if (bw->type == BW_END) {
+                        int len = strlen(bw->word);
+
+                        if (!strnicmp
+                            (nbuf + strlen(nbuf) - len, bw->word, len)) {
+                            mustkick = 1;
+                        } else {
+                            char *wordbuf = scalloc(len + 2, 1);
+
+                            memcpy(wordbuf, bw->word, len);
+                            wordbuf[len] = ' ';
+                            wordbuf[len + 1] = '\0';
+
+                            if (stristr(nbuf, wordbuf))
+                                mustkick = 1;
+
+                            free(wordbuf);
+                        }
                     }
-                } else if (bw->type == BW_START) {
-                    int len = strlen(bw->word);
 
-                    if (!strnicmp(buf, bw->word, len)) {
-                        mustkick = 1;
-                    } else {
-                        char *wordbuf = scalloc(len + 2, 1);
-
-                        memcpy(wordbuf + 1, bw->word, len);
-                        wordbuf[0] = ' ';
-                        wordbuf[len + 1] = '\0';
-
-                        if (stristr(buf, wordbuf))
-                            mustkick = 1;
-
-                        free(wordbuf);
-                    }
-                } else if (bw->type == BW_END) {
-                    int len = strlen(bw->word);
-
-                    if (!strnicmp(buf + strlen(buf) - len, bw->word, len)) {
-                        mustkick = 1;
-                    } else {
-                        char *wordbuf = scalloc(len + 2, 1);
-
-                        memcpy(wordbuf, bw->word, len);
-                        wordbuf[len] = ' ';
-                        wordbuf[len + 1] = '\0';
-
-                        if (stristr(buf, wordbuf))
-                            mustkick = 1;
-
-                        free(wordbuf);
+                    if (mustkick) {
+                        check_ban(ci, u, TTB_BADWORDS);
+                        if (BSGentleBWReason)
+                            bot_kick(ci, u, BOT_REASON_BADWORD_GENTLE);
+                        else
+                            bot_kick(ci, u, BOT_REASON_BADWORD, bw->word);
+                        if (nbuf)
+                            free(nbuf);
+                        return;
                     }
                 }
-
-                if (mustkick) {
-                    check_ban(ci, u, TTB_BADWORDS);
-                    if (BSGentleBWReason)
-                        bot_kick(ci, u, BOT_REASON_BADWORD_GENTLE);
-                    else
-                        bot_kick(ci, u, BOT_REASON_BADWORD, bw->word);
-                    return;
-                }
+                /* Free the normalized buffer */
+                if (nbuf)
+                    free(nbuf);
             }
         }
 
@@ -930,11 +942,11 @@ void bot_join(ChannelInfo * ci)
                      ci->c->name, ci->bi->nick, ci->bi->nick);
     }
 #ifdef IRC_BAHAMUT
-    send_cmd(ci->bi->nick, "SJOIN %ld %s", ci->c->creation_time,
+    send_cmd(ci->bi->nick, "SJOIN %ld %s", (long int) ci->c->creation_time,
              ci->c->name);
 #elif defined(IRC_HYBRID)
-    send_cmd(NULL, "SJOIN %ld %s + :%s", time(NULL), ci->c->name,
-             ci->bi->nick);
+    send_cmd(NULL, "SJOIN %ld %s + :%s", (long int) time(NULL),
+             ci->c->name, ci->bi->nick);
 #else
     send_cmd(ci->bi->nick, "JOIN %s", ci->c->name);
 #endif
@@ -2510,3 +2522,53 @@ static int do_act(User * u)
 }
 
 /*************************************************************************/
+char *normalizeBuffer(const char *buf)
+{
+    char *newbuf = NULL;
+    int i, len, j = 0;
+
+    len = strlen(buf);
+    newbuf = (char *) malloc(sizeof(char) * len + 1);
+
+    for (i = 0; i < len; i++) {
+        switch (buf[i]) {
+            /* Bold ctrl char */
+        case 2:
+            break;
+            /* Color ctrl char */
+        case 3:
+            /* If the next character is a digit, its also removed */
+            if (isdigit(buf[i + 1])) {
+                i++;
+
+                /* Check for background color code
+                 * and remove it as well
+                 */
+                if (buf[i + 1] == ',') {
+                    i++;
+
+                    if (isdigit(buf[i + 1]))
+                        i++;
+                }
+            }
+
+            break;
+
+            /* Reverse ctrl char */
+        case 22:
+            break;
+            /* Underline ctrl char */
+        case 31:
+            break;
+            /* A valid char gets copied into the new buffer */
+        default:
+            newbuf[j] = buf[i];
+            j++;
+        }
+    }
+
+    /* Terminate the string */
+    newbuf[j] = 0;
+
+    return (newbuf);
+}
