@@ -8,7 +8,7 @@
  * Based on the original code of Epona by Lara.
  * Based on the original code of Services by Andy Church. 
  * 
- * $Id: config.c 5 2004-03-29 01:29:50Z dane $ 
+ * $Id: config.c 389 2004-10-12 02:43:40Z trystan $ 
  *
  */
 
@@ -391,7 +391,7 @@ Directive directives[] = {
     {"CSAutokickMax", {{PARAM_POSINT, PARAM_RELOAD, &CSAutokickMax}}},
     {"CSAutokickReason",
      {{PARAM_STRING, PARAM_RELOAD, &CSAutokickReason}}},
-    {"CSDefBantype", {{PARAM_POSINT, PARAM_RELOAD, &CSDefBantype}}},
+    {"CSDefBantype", {{PARAM_INT, PARAM_RELOAD, &CSDefBantype}}},
     {"CSDefNone", {{PARAM_SET, PARAM_RELOAD, &CSDefNone}}},
     {"CSDefKeepTopic", {{PARAM_SET, PARAM_RELOAD, &CSDefKeepTopic}}},
     {"CSDefOpNotice", {{PARAM_SET, PARAM_RELOAD, &CSDefOpNotice}}},
@@ -455,8 +455,8 @@ Directive directives[] = {
                       {PARAM_STRING, 0, &desc_HelpServ}}},
     {"HelpServAlias", {{PARAM_STRING, 0, &s_HelpServAlias},
                        {PARAM_STRING, 0, &desc_HelpServAlias}}},
-    {"KeepBackups", {{PARAM_POSINT, PARAM_RELOAD, &KeepBackups}}},
-    {"KeepLogs", {{PARAM_POSINT, PARAM_RELOAD, &KeepLogs}}},
+    {"KeepBackups", {{PARAM_INT, PARAM_RELOAD, &KeepBackups}}},
+    {"KeepLogs", {{PARAM_INT, PARAM_RELOAD, &KeepLogs}}},
     {"KillClones", {{PARAM_SET, PARAM_FULLONLY, &KillClones}}},
     {"AddAkiller", {{PARAM_SET, PARAM_RELOAD, &AddAkiller}}},
     {"KillClonesAkillExpire",
@@ -470,7 +470,7 @@ Directive directives[] = {
     {"SuperAdmin", {{PARAM_SET, PARAM_RELOAD, &SuperAdmin}}},
     {"LogMaxUsers", {{PARAM_SET, PARAM_RELOAD, &LogMaxUsers}}},
     {"MailDelay", {{PARAM_TIME, PARAM_RELOAD, &MailDelay}}},
-    {"MaxSessionKill", {{PARAM_POSINT, PARAM_RELOAD, &MaxSessionKill}}},
+    {"MaxSessionKill", {{PARAM_INT, PARAM_RELOAD, &MaxSessionKill}}},
     {"MaxSessionLimit", {{PARAM_POSINT, PARAM_RELOAD, &MaxSessionLimit}}},
     {"MemoServName", {{PARAM_STRING, 0, &s_MemoServ},
                       {PARAM_STRING, 0, &desc_MemoServ}}},
@@ -526,7 +526,7 @@ Directive directives[] = {
      {{PARAM_STRING, PARAM_RELOAD, &NSGuestNickPrefix}}},
     {"NSListMax", {{PARAM_POSINT, PARAM_RELOAD, &NSListMax}}},
     {"NSListOpersOnly", {{PARAM_SET, PARAM_RELOAD, &NSListOpersOnly}}},
-    {"NSMaxAliases", {{PARAM_POSINT, PARAM_RELOAD, &NSMaxAliases}}},
+    {"NSMaxAliases", {{PARAM_INT, PARAM_RELOAD, &NSMaxAliases}}},
     {"NSNoGroupChange", {{PARAM_SET, PARAM_RELOAD, &NSNoGroupChange}}},
     {"NSRegDelay", {{PARAM_TIME, PARAM_RELOAD, &NSRegDelay}}},
     {"NSReleaseTimeout", {{PARAM_TIME, PARAM_RELOAD, &NSReleaseTimeout}}},
