@@ -8,7 +8,7 @@
  * Based on the original code of Epona by Lara.
  * Based on the original code of Services by Andy Church. 
  * 
- * $Id: hostserv.c 5 2004-03-29 01:29:50Z dane $ 
+ * $Id: hostserv.c 177 2004-06-07 19:55:27Z dane $ 
  *
  */
 
@@ -824,8 +824,9 @@ static int do_help(User * u)
         notice_help(s_HostServ, u, HOST_HELP, s_HostServ);
         if ((is_services_oper(u)) || (is_host_setter(u)))
             notice_help(s_HostServ, u, HOST_OPER_HELP);
-        if (is_services_admin(u))
-            notice_help(s_HostServ, u, HOST_ADMIN_HELP);
+        /* Removed as atm, there is no admin only help */
+        /*if (is_services_admin(u))
+           notice_help(s_HostServ, u, HOST_ADMIN_HELP); */
         moduleDisplayHelp(6, u);
     } else {
         mod_help_cmd(s_HostServ, u, HOSTSERV, cmd);
