@@ -8,7 +8,7 @@
  * Based on the original code of Epona by Lara.
  * Based on the original code of Services by Andy Church. 
  * 
- * $Id: init.c 5 2004-03-29 01:29:50Z dane $ 
+ * $Id: init.c 420 2004-10-23 23:42:15Z trystan $ 
  *
  */
 
@@ -27,34 +27,34 @@ extern void moduleAddMsgs(void);
 # define NICK(nick,name,modes) \
     do { \
 	kill_user(NULL, (nick), "Nick used by Services"); \
-	send_cmd(NULL, "NICK %s 1 %ld %s %s %s %s :%s", (nick), time(NULL), (modes), \
+	send_cmd(NULL, "NICK %s 1 %ld %s %s %s %s :%s", (nick), (long int) time(NULL), (modes), \
 		ServiceUser, ServiceHost, ServerName, (name)); \
 	} while (0)
 #elif defined(IRC_ULTIMATE3)
 # define NICK(nick,name,modes) \
     do { \
-	send_cmd(NULL, "CLIENT %s 1 %ld %s + %s %s * %s 0 0 :%s", (nick), time(NULL), (modes), \
+	send_cmd(NULL, "CLIENT %s 1 %ld %s + %s %s * %s 0 0 :%s", (nick), (long int) time(NULL), (modes), \
 		ServiceUser, ServiceHost, ServerName, (name)); \
 	send_cmd(NULL, "SQLINE %s :Reserved for services", (nick)); \
 	} while (0)
 #elif defined(IRC_BAHAMUT)
 # define NICK(nick,name,modes) \
     do { \
-	send_cmd(NULL, "NICK %s 1 %ld %s %s %s %s 0 0 :%s", (nick), time(NULL), (modes), \
+	send_cmd(NULL, "NICK %s 1 %ld %s %s %s %s 0 0 :%s", (nick), (long int) time(NULL), (modes), \
 		ServiceUser, ServiceHost, ServerName, (name)); \
 	send_cmd(NULL, "SQLINE %s :Reserved for services", (nick)); \
 	} while (0)
 #elif defined(IRC_UNREAL)
 # define NICK(nick,name,modes) \
     do { \
-	send_cmd(NULL, "NICK %s 1 %ld %s %s %s 0 %s * :%s", (nick), time(NULL), \
+	send_cmd(NULL, "NICK %s 1 %ld %s %s %s 0 %s * :%s", (nick), (long int) time(NULL), \
 		ServiceUser, ServiceHost, ServerName, (modes), (name)); \
 	send_cmd(NULL, "SQLINE %s :Reserved for services", (nick)); \
     } while (0)
 #elif defined(IRC_DREAMFORGE)
 # define NICK(nick,name,modes) \
     do { \
-	send_cmd(NULL, "NICK %s 1 %ld %s %s %s 0 :%s", (nick), time(NULL), \
+	send_cmd(NULL, "NICK %s 1 %ld %s %s %s 0 :%s", (nick), (long int) time(NULL), \
 		ServiceUser, ServiceHost, ServerName, (name)); \
 	if (strcmp(modes, "+")) send_cmd((nick), "MODE %s %s", (nick), (modes)); \
 	send_cmd(NULL, "SQLINE %s :Reserved for services", (nick)); \
@@ -62,8 +62,9 @@ extern void moduleAddMsgs(void);
 #elif defined(IRC_PTLINK)
 # define NICK(nick,name,modes) \
     do { \
-        send_cmd(NULL, "NICK %s 1 %lu %s %s %s %s %s :%s", (nick), time(NULL), \
+        send_cmd(NULL, "NICK %s 1 %lu %s %s %s %s %s :%s", (nick), (long int) time(NULL), \
                 (modes), ServiceUser, ServiceHost, ServiceHost, ServerName, (name)); \
+	send_cmd(NULL, "SQLINE %s :Reserved for services", (nick)); \
     } while (0)
 #endif
 
@@ -416,10 +417,6 @@ static int parse_options(int ac, char **av)
                 nofork = 1;
             } else if (strcmp(s, "logchan") == 0) {
                 logchan = 1;
-#ifdef IRC_HYBRID
-                fprintf(stderr,
-                        "LogChan will only work if your logchannel is not set to +n\n");
-#endif
             } else if (strcmp(s, "forceload") == 0) {
                 forceload = 1;
             } else if (!strcmp(s, "noexpire")) {
@@ -644,35 +641,42 @@ int init(int ac, char **av)
     if (!skeleton) {
         load_ns_dbase();
         if (debug)
-            alog("debug: Loaded %s database (1/9)", s_NickServ);
+            alog("debug: Loaded %s database (1/%d)", s_NickServ,
+                 (PreNickDBName ? 8 : 7));
         if (s_HostServ) {
             load_hs_dbase();
             if (debug)
-                alog("debug: Loaded %s database (2/9)", s_HostServ);
+                alog("debug: Loaded %s database (2/%d)", s_HostServ,
+                     (PreNickDBName ? 8 : 7));
         }
         if (s_BotServ) {
             load_bs_dbase();
             if (debug)
-                alog("debug: Loaded %s database (3/9)", s_BotServ);
+                alog("debug: Loaded %s database (3/%d)", s_BotServ,
+                     (PreNickDBName ? 8 : 7));
         } else if (debug)
-            alog("debug: BotServ database (4/9) not loaded because BotServ is disabled");
+            alog("debug: BotServ database (3/%d) not loaded because BotServ is disabled", (PreNickDBName ? 8 : 7));
         load_cs_dbase();
         if (debug)
-            alog("debug: Loaded %s database (5/9)", s_ChanServ);
+            alog("debug: Loaded %s database (4/%d)", s_ChanServ,
+                 (PreNickDBName ? 8 : 7));
     }
     load_os_dbase();
     if (debug)
-        alog("debug: Loaded %s database (6/9)", s_OperServ);
+        alog("debug: Loaded %s database (5/%d)", s_OperServ,
+             (PreNickDBName ? 8 : 7));
     load_news();
     if (debug)
-        alog("debug: Loaded news database (7/9)");
+        alog("debug: Loaded news database (6/%d)",
+             (PreNickDBName ? 8 : 7));
     load_exceptions();
     if (debug)
-        alog("debug: Loaded exception database (8/9)");
+        alog("debug: Loaded exception database (7/%d)",
+             (PreNickDBName ? 8 : 7));
     if (PreNickDBName) {
         load_ns_req_db();
         if (debug)
-            alog("debug: Loaded PreNick database (9/9)");
+            alog("debug: Loaded PreNick database (8/8)");
     }
 
     alog("Databases loaded");
@@ -761,14 +765,14 @@ int init(int ac, char **av)
     send_cmd(NULL, "SERVER %s 1 :%s", ServerName, ServerDesc);
 #endif
 #ifdef IRC_BAHAMUT
-    send_cmd(NULL, "SVINFO 3 1 0 :%ld", time(NULL));
+    send_cmd(NULL, "SVINFO 3 1 0 :%ld", (long int) time(NULL));
 #endif
 #ifdef IRC_HYBRID
-    send_cmd(NULL, "SVSINFO 5 5 0 :%ld", time(NULL));
+    send_cmd(NULL, "SVSINFO 5 5 0 :%ld", (long int) time(NULL));
 #endif
 #ifdef IRC_PTLINK
-    send_cmd(NULL, "SVINFO 3 6 %lu", time(NULL));
-    send_cmd(NULL, "SVSINFO %lu %d", time(NULL), maxusercnt);
+    send_cmd(NULL, "SVINFO 3 6 %lu", (long int) time(NULL));
+    send_cmd(NULL, "SVSINFO %lu %d", (long int) time(NULL), maxusercnt);
 #endif
     sgets2(inbuf, sizeof(inbuf), servsock);
     if (strnicmp(inbuf, "ERROR", 5) == 0) {
@@ -788,6 +792,14 @@ int init(int ac, char **av)
     /* Bring in our pseudo-clients */
     introduce_user(NULL);
 
+    /* And hybrid needs Global joined in the logchan */
+#ifdef IRC_HYBRID
+    if (logchan) {
+        send_cmd(NULL, "SJOIN %ld %s + :%s", (long int) time(NULL),
+                 LogChannel, s_GlobalNoticer);
+    }
+#endif
+
     /**
       * Load our delayed modeles - modules that are planing on making clients need to wait till now
       * where as modules wanting to modify our ircd connection messages need to load eariler :|
@@ -797,7 +809,7 @@ int init(int ac, char **av)
     /* Write the StartGlobal */
     if (GlobalOnCycle) {
         if (GlobalOnCycleUP)
-            oper_global(NULL, GlobalOnCycleUP);
+            oper_global(NULL, "%s", GlobalOnCycleUP);
     }
 
     /* Success! */
