@@ -8,7 +8,7 @@
  * Based on the original code of Epona by Lara.
  * Based on the original code of Services by Andy Church.
  *
- * $Id: messages.c 5 2004-03-29 01:29:50Z dane $
+ * $Id: messages.c 420 2004-10-23 23:42:15Z trystan $
  *
  */
 
@@ -553,9 +553,12 @@ static int m_privmsg(char *source, int ac, char **av)
     }
 
     if (*av[0] == '#') {
-        if (s_BotServ && (ci = cs_findchan(av[0])))
-            if (!(ci->flags & CI_VERBOTEN) && ci->c && ci->bi)  /* Some paranoia checks */
+        if (s_BotServ && (ci = cs_findchan(av[0]))) {
+            if (!(ci->flags & CI_VERBOTEN) && ci->c && ci->bi) {
+                /* Some paranoia checks */
                 botchanmsgs(u, ci, av[1]);
+            }
+        }
     } else {
 
         /* Check if we should ignore.  Operators always get through. */
@@ -840,7 +843,7 @@ static int m_stats(char *source, int ac, char **av)
                 send_cmd(NULL, "211 %s %s %d %d %d %d %d %d %ld", source,
                          RemoteServer, write_buffer_len(), total_written,
                          -1, read_buffer_len(), total_read, -1,
-                         time(NULL) - start_time);
+                         (long int) time(NULL) - start_time);
             } else if (servernum == 2) {
                 send_cmd(NULL,
                          "211 %s Server SendBuf SentBytes SentMsgs RecvBuf "
@@ -848,7 +851,7 @@ static int m_stats(char *source, int ac, char **av)
                 send_cmd(NULL, "211 %s %s %d %d %d %d %d %d %ld", source,
                          RemoteServer2, write_buffer_len(), total_written,
                          -1, read_buffer_len(), total_read, -1,
-                         time(NULL) - start_time);
+                         (long int) time(NULL) - start_time);
             } else if (servernum == 3) {
                 send_cmd(NULL,
                          "211 %s Server SendBuf SentBytes SentMsgs RecvBuf "
@@ -856,7 +859,7 @@ static int m_stats(char *source, int ac, char **av)
                 send_cmd(NULL, "211 %s %s %d %d %d %d %d %d %ld", source,
                          RemoteServer3, write_buffer_len(), total_written,
                          -1, read_buffer_len(), total_read, -1,
-                         time(NULL) - start_time);
+                         (long int) time(NULL) - start_time);
             }
         }
 
@@ -1014,8 +1017,8 @@ int m_whois(char *source, int ac, char **av)
                      ServerName, ServerDesc);
             send_cmd(ServerName,
                      "317 %s %s %ld %ld :seconds idle, signon time",
-                     source, bi->nick, time(NULL) - bi->lastmsg,
-                     start_time);
+                     source, bi->nick, (long int) time(NULL) - bi->lastmsg,
+                     (long int) start_time);
             send_cmd(ServerName, "318 %s %s :End of /WHOIS list.", source,
                      bi->nick);
             return MOD_CONT;
@@ -1030,7 +1033,8 @@ int m_whois(char *source, int ac, char **av)
                  ServerDesc);
         send_cmd(ServerName,
                  "317 %s %s %ld %ld :seconds idle, signon time", source,
-                 av[0], time(NULL) - start_time, start_time);
+                 av[0], (long int) time(NULL) - start_time,
+                 (long int) start_time);
         send_cmd(ServerName, "318 %s %s :End of /WHOIS list.", source,
                  av[0]);
     }
