@@ -8,7 +8,7 @@
  * Based on the original code of Epona by Lara.
  * Based on the original code of Services by Andy Church.
  *
- * $Id: modules.c 31 2004-04-04 11:01:46Z rob $
+ * $Id: modules.c 419 2004-10-23 17:59:28Z trystan $
  *
  */
 #include "modules.h"
@@ -1153,7 +1153,7 @@ int moduleAddCallback(char *name, time_t when,
     }
     if (debug)
         alog("Added module CallBack: [%s] due to execute at %ld",
-             new->name ? new->name : "?", new->when);
+             new->name ? new->name : "?", (long int) new->when);
     return MOD_ERR_OK;
 }
 
