@@ -8,7 +8,7 @@
  * Based on the original code of Epona by Lara.
  * Based on the original code of Services by Andy Church. 
  * 
- * $Id: mysql.c 60 2004-04-18 14:07:35Z dane $ 
+ * $Id: mysql.c 863 2005-08-29 14:19:39Z geniusdex $ 
  *
  */
 #include "services.h"
@@ -57,9 +57,22 @@ int db_mysql_init()
     } else {
         do_mysql = 1;
         alog("MySQL has been enabled.");
+        alog("MySQL client version %s.", mysql_get_client_info());
     }
-    return 1;
 
+    /* The following configuration options are required.
+     * If missing disable MySQL to avoid any problems.
+     */
+
+    if ((do_mysql) && (!MysqlName || !MysqlUser)) {
+        do_mysql = 0;
+        alog("MySQL Error: Set all required configuration options.");
+    }
+
+    if (!db_mysql_open())
+        do_mysql = 0;
+
+    return 1;
 }
 
 /*************************************************************************/
@@ -378,10 +391,16 @@ void db_mysql_save_cs_info(ChannelInfo * ci)
         *cbadwords, *efounderpass;
 
     ciname = db_mysql_quote(ci->name);
-    cifoundernick =
-        ci->founder ? db_mysql_quote(ci->founder->display) : "";
-    cisuccessornick =
-        ci->successor ? db_mysql_quote(ci->successor->display) : "";
+    if (ci->founder) {
+        cifoundernick = db_mysql_quote(ci->founder->display);
+    } else {
+        cifoundernick = db_mysql_quote("");
+    }
+    if (ci->successor) {
+        cisuccessornick = db_mysql_quote(ci->successor->display);
+    } else {
+        cisuccessornick = db_mysql_quote("");
+    }
     cifounderpass = db_mysql_quote(ci->founderpass);
     cidesc = db_mysql_quote(ci->desc);
     ciurl = db_mysql_quote(ci->url);
@@ -402,7 +421,11 @@ void db_mysql_save_cs_info(ChannelInfo * ci)
     cimlock_redirect = NULL;
 #endif
     cientrymsg = db_mysql_quote(ci->entry_message);
-    cibotnick = ci->bi ? db_mysql_quote(ci->bi->nick) : "";
+    if (ci->bi) {
+        cibotnick = db_mysql_quote(ci->bi->nick);
+    } else {
+        cibotnick = db_mysql_quote("");
+    }
 
     efounderpass = db_mysql_secure(cifounderpass);
     free(cifounderpass);
@@ -594,26 +617,21 @@ void db_mysql_save_cs_info(ChannelInfo * ci)
     }
 
     free(ciname);
-    if (!(ci->flags & CI_VERBOTEN)) {
-        free(cifoundernick);
-        if (strlen(cisuccessornick) > 0)
-            free(cisuccessornick);
-        free(efounderpass);
-        free(cidesc);
-        free(ciurl);
-        free(ciemail);
-        free(cilasttopic);
-        free(cilasttopicsetter);
-        free(cimlock_key);
-        free(cimlock_flood);
-        free(cimlock_redirect);
-        free(cientrymsg);
-        if (ci->bi)
-            free(cibotnick);
-    } else {
-        free(ciforbidby);
-        free(ciforbidreason);
-    }
+    free(cifoundernick);
+    free(cisuccessornick);
+    free(efounderpass);
+    free(cidesc);
+    free(ciurl);
+    free(ciemail);
+    free(cilasttopic);
+    free(cilasttopicsetter);
+    free(cimlock_key);
+    free(cimlock_flood);
+    free(cimlock_redirect);
+    free(cientrymsg);
+    free(cibotnick);
+    free(ciforbidby);
+    free(ciforbidreason);
 
     return;
 }
