@@ -8,7 +8,7 @@
  * Based on the original code of Epona by Lara.
  * Based on the original code of Services by Andy Church. 
  * 
- * $Id: proxy.c 5 2004-03-29 01:29:50Z dane $ 
+ * $Id: proxy.c 863 2005-08-29 14:19:39Z geniusdex $ 
  *
  */
 
@@ -261,7 +261,8 @@ static int proxy_connect(unsigned long ip, unsigned short port)
 
     fd_set fds;
     struct timeval tv;
-    int error, errlen;
+    int error;
+    socklen_t errlen;
 
     if ((s = socket(PF_INET, SOCK_STREAM, 0)) == -1)
         return -1;
