@@ -746,34 +746,34 @@ struct user_ {
 # define NEWNICK(nick,user,host,real,modes,qline) \
     do { \
 	kill_user(NULL, (nick), "Nick used by Services"); \
-	send_cmd(NULL, "NICK %s 1 %ld %s %s %s %s :%s", (nick), time(NULL), (modes), \
+	send_cmd(NULL, "NICK %s 1 %ld %s %s %s %s :%s", (nick), (long int) time(NULL), (modes), \
 		(user), (host), ServerName, (real)); \
 	} while (0)
 #elif defined(IRC_ULTIMATE3)
 # define NEWNICK(nick,user,host,real,modes,qline) \
     do { \
-	send_cmd(NULL, "CLIENT %s 1 %ld %s + %s %s * %s 0 0 :%s", (nick), time(NULL), (modes), \
+	send_cmd(NULL, "CLIENT %s 1 %ld %s + %s %s * %s 0 0 :%s", (nick), (long int) time(NULL), (modes), \
 		(user), (host), ServerName, (real)); \
 	if ((qline)) send_cmd(NULL, "SQLINE %s :Reserved for services", (nick)); \
     } while (0)
 #elif defined(IRC_BAHAMUT) && !defined(IRC_ULTIMATE3)
 # define NEWNICK(nick,user,host,real,modes,qline) \
     do { \
-	send_cmd(NULL, "NICK %s 1 %ld %s %s %s %s 0 0 :%s", (nick), time(NULL), (modes), \
+	send_cmd(NULL, "NICK %s 1 %ld %s %s %s %s 0 0 :%s", (nick), (long int) time(NULL), (modes), \
 		(user), (host), ServerName, (real)); \
 	if ((qline)) send_cmd(NULL, "SQLINE %s :Reserved for services", (nick)); \
     } while (0)
 #elif defined(IRC_UNREAL)
 # define NEWNICK(nick,user,host,real,modes,qline) \
     do { \
-	send_cmd(NULL, "NICK %s 1 %ld %s %s %s 0 %s * :%s", (nick), time(NULL), \
+	send_cmd(NULL, "NICK %s 1 %ld %s %s %s 0 %s * :%s", (nick), (long int) time(NULL), \
 		(user), (host), ServerName, (modes), (real)); \
 	if ((qline)) send_cmd(NULL, "SQLINE %s :Reserved for services", (nick)); \
     } while (0)
 #elif defined(IRC_DREAMFORGE)
 # define NEWNICK(nick,user,host,real,modes,qline) \
     do { \
-	send_cmd(NULL, "NICK %s 1 %ld %s %s %s 0 :%s", (nick), time(NULL), \
+	send_cmd(NULL, "NICK %s 1 %ld %s %s %s 0 :%s", (nick), (long int) time(NULL), \
 		(user), (host), ServerName, (real)); \
 	if (strcmp(modes, "+")) send_cmd((nick), "MODE %s %s", (nick), (modes)); \
 	if ((qline)) send_cmd(NULL, "SQLINE %s :Reserved for services", (nick)); \
@@ -781,7 +781,7 @@ struct user_ {
 #elif defined(IRC_PTLINK)
 # define NEWNICK(nick,user,host,real,modes,qline) \
     do { \
-        send_cmd(NULL, "NICK %s 1 %lu %s %s %s %s %s :%s", (nick), time(NULL), \
+        send_cmd(NULL, "NICK %s 1 %lu %s %s %s %s %s :%s", (nick), (long int) time(NULL), \
                 (modes), (user), (host), (host), ServerName, (real)); \
        if ((qline)) send_cmd(NULL, "SQLINE %s :Reserved for services", (nick)); \
     } while (0)
