@@ -8,7 +8,7 @@
  * Based on the original code of Epona by Lara.
  * Based on the original code of Services by Andy Church. 
  * 
- * $Id: users.c 5 2004-03-29 01:29:50Z dane $
+ * $Id: users.c 420 2004-10-23 23:42:15Z trystan $
  *
  */
 
@@ -548,6 +548,8 @@ User *do_nick(const char *source, char *nick, char *username, char *host,
 
 #ifdef HAS_NICKIP
         ip = va_arg(args, uint32);
+        addr.s_addr = htonl(ip);
+        ntoa(addr, ipbuf, sizeof(ipbuf));
 #endif
 
 #ifdef HAS_NICKVHOST
@@ -577,10 +579,6 @@ User *do_nick(const char *source, char *nick, char *username, char *host,
 	 * End of ugly swap
 	 **/
 
-#ifdef HAS_NICKIP
-            addr.s_addr = htonl(ip);
-            ntoa(addr, ipbuf, sizeof(ipbuf));
-#endif
 
 #ifdef HAS_NICKVHOST
 # ifdef HAS_NICKIP
@@ -710,7 +708,7 @@ User *do_nick(const char *source, char *nick, char *username, char *host,
             user->svid = 1;
 #ifdef IRC_BAHAMUT
             send_cmd(ServerName, "SVSMODE %s %lu +d 1", user->nick,
-                     user->timestamp);
+                     (unsigned long int) user->timestamp);
 #else
 #ifndef IRC_PTLINK
             send_cmd(ServerName, "SVSMODE %s +d 1", user->nick);
